@@ -392,6 +392,9 @@ class ComboEntry(gtk.VBox):
         if not entry:
             entry = KiwiEntry()
 
+        if isinstance(entry, KiwiEntry):
+            entry.set_normal_completion()
+
         self.hbox = gtk.HBox()
         self.pack_start(gtk.EventBox())
         self.pack_start(self.hbox, expand=False)
@@ -503,7 +506,7 @@ class ComboEntry(gtk.VBox):
 
     def _on_popup__text_selected(self, popup, text):
         self.set_text(text)
-        popup.popdown()
+        self.popdown()
         self.entry.grab_focus()
         self.entry.set_position(len(self.entry.get_text()))
         self.emit('changed')
@@ -541,6 +544,14 @@ class ComboEntry(gtk.VBox):
         Hide the popup window
         """
         self._popup.popdown()
+        # FIXME: This is a very ugly hack. For some reason, data is not
+        # set when typing or pressing enter on the completion. It only works
+        # with the mouse (both clicking on completion and scrolling results).
+        # Find out why this happens and remove the try/except bellow.
+        try:
+            self.select_item_by_label(self.entry.get_text())
+        except KeyError:
+            pass
 
     def set_text(self, text):
         """
@@ -627,6 +638,11 @@ class ComboEntry(gtk.VBox):
         """
         See :class:`kiwi.interfaces.IEasyCombo.prefill`
         """
+        if not itemdata:
+            # If itemdata has no items, just clear
+            self.clear()
+            return
+
         self._model.clear()
         self.entry.prefill(itemdata, sort)
         self.mode = self.entry.get_mode()
