@@ -854,7 +854,7 @@ class StringSearchFilter(SearchFilter):
     # Public API
     #
 
-    def enable_advaced(self):
+    def enable_advanced(self):
         self.mode.show()
 
     def set_label(self, label):
@@ -1086,6 +1086,7 @@ class SearchContainer(gtk.VBox):
         self._query_executer = None
         self._search_filters = []
         self._summary_label = None
+        self.menu = None
 
         search_filter = StringSearchFilter(_('Search:'), chars=chars,
                                            container=self)
@@ -1111,28 +1112,6 @@ class SearchContainer(gtk.VBox):
         else:
             raise AssertionError(pspec.name)
 
-    #
-    # GtkContainer
-    #
-
-    def do_set_child_property(self, child, property_id, value, pspec):
-        if pspec.name == 'filter-position':
-            if value == 'top':
-                pos = SearchFilterPosition.TOP
-            elif value == 'bottom':
-                pos = SearchFilterPosition.BOTTOM
-            else:
-                raise Exception(pos)
-            self.set_filter_position(child, pos)
-        else:
-            raise AssertionError(pspec.name)
-
-    def do_get_child_property(self, child, property_id, pspec):
-        if pspec.name == 'filter-position':
-            return self.get_filter_position(child)
-        else:
-            raise AssertionError(pspec.name)
-
     #
     # Public API
     #
@@ -1181,6 +1160,51 @@ class SearchContainer(gtk.VBox):
         if self._auto_search:
             self.search()
 
+    def add_filter_by_column(self, column):
+        """Add a filter accordingly to the column specification
+
+        :param column: a SearchColumn instance
+        """
+        title = (column.long_title or column.title) + ':'
+
+        if column.data_type == datetime.date:
+            filter = DateSearchFilter(title)
+            if column.valid_values:
+                filter.clear_options()
+                filter.add_custom_options()
+                for opt in column.valid_values:
+                    filter.add_option(opt)
+                filter.select(column.valid_values[0])
+
+        elif (column.data_type == Decimal or
+              column.data_type == int or
+              column.data_type == currency):
+            filter = NumberSearchFilter(title)
+            if column.data_type != int:
+                filter.set_digits(2)
+        elif column.data_type == str:
+            if column.valid_values:
+                filter = ComboSearchFilter(title, column.valid_values)
+            else:
+                filter = StringSearchFilter(title)
+                filter.enable_advanced()
+        else:
+            # TODO: Boolean
+            raise NotImplementedError(title, column.data_type)
+
+        filter.set_removable()
+        attr = column.search_attribute or column.attribute
+        self.add_filter(filter, columns=[attr])
+
+        label = filter.get_title_label()
+        label.set_alignment(1.0, 0.5)
+        self.label_group.add_widget(label)
+        combo = filter.get_mode_combo()
+        if combo:
+            self.combo_group.add_widget(combo)
+
+        return filter
+
     def get_search_filters(self):
         return self._search_filters
 
@@ -1217,16 +1241,16 @@ class SearchContainer(gtk.VBox):
         else:
             raise AssertionError(search_filter)
 
-    def set_query_executer(self, querty_executer):
+    def set_query_executer(self, query_executer):
         """
         Ties a QueryExecuter instance to the SearchContainer class
         :param querty_executer: a querty executer
         :type querty_executer: a :class:`QueryExecuter` subclass
         """
-        if not isinstance(querty_executer, QueryExecuter):
-            raise TypeError("querty_executer must be a QueryExecuter instance")
+        if not isinstance(query_executer, QueryExecuter):
+            raise TypeError("query_executer must be a QueryExecuter instance")
 
-        self._query_executer = querty_executer
+        self._query_executer = query_executer
 
     def get_query_executer(self):
         """
@@ -1333,7 +1357,7 @@ class SearchContainer(gtk.VBox):
                                                   column=column,
                                                   label=label,
                                                   value_format=format)
-        parent.pack_end(self._summary_label, False, False)
+        parent.pack_start(self._summary_label, False, False)
         self._summary_label.show()
 
     @property
@@ -1345,8 +1369,6 @@ class SearchContainer(gtk.VBox):
 
     def add_results(self, results, clear=True):
         if clear:
-            if self._lazy_updater:
-                self._lazy_updater.restore_model()
             self.results.clear()
 
         if self._lazy_updater:
@@ -1411,7 +1433,7 @@ class SearchContainer(gtk.VBox):
         self._create_basic_search()
 
         self.results = self.results_class(self._columns)
-        self.pack_end(self.results, True, True, 0)
+        self.pack_start(self.results, True, True, 0)
         self.results.show()
 
     def _create_basic_search(self):
@@ -1463,54 +1485,10 @@ class SearchContainer(gtk.VBox):
 
     def _on_menu_item_activate(self, item):
         column = item.get_data('column')
-
         if column is None:
             return
 
-        title = (column.long_title or column.title) + ':'
-
-        if column.data_type == datetime.date:
-            filter = DateSearchFilter(title)
-            if column.valid_values:
-                filter.clear_options()
-                filter.add_custom_options()
-                for opt in column.valid_values:
-                    filter.add_option(opt)
-                filter.select(column.valid_values[0])
-
-        elif (column.data_type == Decimal or
-              column.data_type == int or
-              column.data_type == currency):
-            filter = NumberSearchFilter(title)
-            if column.data_type != int:
-                filter.set_digits(2)
-        elif column.data_type == str:
-            if column.valid_values:
-                filter = ComboSearchFilter(title, column.valid_values)
-            else:
-                filter = StringSearchFilter(title)
-                filter.enable_advaced()
-        else:
-            # TODO: Boolean
-            raise NotImplementedError
-
-        filter.set_removable()
-        attr = column.search_attribute or column.attribute
-        self.add_filter(filter, columns=[attr])
-
-        label = filter.get_title_label()
-        label.set_alignment(1.0, 0.5)
-        self.label_group.add_widget(label)
-        combo = filter.get_mode_combo()
-        if combo:
-            self.combo_group.add_widget(combo)
-
-
-SearchContainer.install_child_property(
-    1, ('filter-position', str,
-        'Search Filter Position',
-        'The search filter position in the container',
-        '', gobject.PARAM_READWRITE))
+        self.add_filter_by_column(column)
 
 
 class SearchSlaveDelegate(SlaveDelegate):
