@@ -1,7 +1,7 @@
 #
 # Kiwi: a Framework and Enhanced Widgets for Python
 #
-# Copyright (C) 2001-2006 Async Open Source
+# Copyright (C) 2001-2012 Async Open Source
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -89,10 +89,33 @@ method_regex = re.compile(r'^(on|after)_(\w+)__(\w+)$')
 
 
 class SignalBroker(object):
-    def __init__(self, view, controller):
-        methods = controller._get_all_methods()
+    def __init__(self, view, controller=None):
+        if controller is None:
+            controller = view
+        methods = self._get_all_methods(controller)
         self._do_connections(view, methods)
 
+    def _get_all_methods(self, controller, klass=None):
+        klass = klass or controller.__class__
+        # Very poor simulation of inheritance, but WFM(tm)
+        classes = [klass]
+        # Collect bases for class, using a pretty evil recursion
+        for klass in classes:
+            map(classes.append, klass.__bases__)
+        # Order bases so that the class itself is the last one referred to
+        # in the loop. This guarantees that the inheritance ordering for the
+        # methods is preserved.
+        classes.reverse()
+        methods = {}
+        for c in classes:
+            for name in c.__dict__.keys():
+                # Need to use getattr() to ensure we get bound methods
+                try:
+                    methods[name] = getattr(controller, name)
+                except AttributeError:
+                    continue
+        return methods
+
     def _do_connections(self, view, methods):
         """This method allows subclasses to add more connection mechanism"""
         self._autoconnect_by_method_name(view, methods)
@@ -208,6 +231,8 @@ class SlaveView(gobject.GObject):
     toplevel_name = None
     gladefile = None
     domain = None
+    fields = None
+    form_holder_name = 'toplevel'
 
     # This signal is emited when the view wants to return a result value
     gsignal("result", object)
@@ -226,10 +251,12 @@ class SlaveView(gobject.GObject):
         self._broker = None
         self.slaves = {}
         self._proxies = []
-        self._valid = True
+        self.is_valid = True
 
         # slave/widget name -> validation status
         self._validation = {}
+        self._forms = {}
+        self._forms_attached = False
 
         # stores the function that will be called when widgets
         # validity is checked
@@ -238,7 +265,7 @@ class SlaveView(gobject.GObject):
         # setup the initial state with the value of the arguments or the
         # class variables
         klass = type(self)
-        self.toplevel = toplevel or klass.toplevel
+        self.toplevel = toplevel or getattr(self, 'toplevel', klass.toplevel)
         self.widgets = widgets or klass.widgets
         self.gladefile = gladefile or klass.gladefile
         self.toplevel_name = (toplevel_name or
@@ -247,6 +274,18 @@ class SlaveView(gobject.GObject):
         self.domain = domain or klass.domain
 
         self._check_reserved()
+
+        # Make it possible to run a view without a glade file, to be able
+        # to attach slaves we need the toplevel widget to be an EventBox.
+        if not self.gladefile and self.toplevel is None:
+            self.toplevel = gtk.Window()
+            self.toplevel.set_name('KiwiViewWindow')
+
+        # Forms create widgets that we want to connect signals to,
+        # so this needs to be done before the View constructor
+        if self.fields:
+            self.add_form(self.fields)
+
         self._glade_adaptor = self.get_glade_adaptor()
         self.toplevel = self._get_toplevel()
 
@@ -261,6 +300,12 @@ class SlaveView(gobject.GObject):
         if len(self._notebooks) == 1:
             register_notebook_shortcuts(self, self._notebooks[0])
 
+        # FIXME: This is a hack to avoid a toplevel window
+        #        showing up, I cannot quite figure out how it works
+        #        probably related to attach_slave(), Johan 2012-06-19
+        if self.fields and not self.gladefile:
+            self.toplevel.hide()
+
     def _get_notebooks(self):
         if not self._glade_adaptor:
             return []
@@ -322,6 +367,33 @@ class SlaveView(gobject.GObject):
 
         return glade_adaptor
 
+    def add_form(self, fields, holder_name=None):
+        """ Adds a new form given a dictionary of fields and attaches
+        it to the view as a slave at the holder_name location.
+        This needs to be called before the View constructor is called.
+        """
+        if holder_name is None:
+            holder_name = self.form_holder_name
+
+        if holder_name in self._forms:
+            raise TypeError(
+                "%r is attached to %r, you need to specify "
+                "another holder name" % (
+                self._forms[holder_name], holder_name))
+        # To avoid a cyclic dependency between forms & views
+        from kiwi.ui.forms import BasicForm
+        form = BasicForm(self)
+        form.build(fields)
+        self._forms[holder_name] = form
+
+    def _attach_forms(self):
+        for holder_name, form in self._forms.items():
+            self.attach_slave(holder_name, form)
+            form.populate(self.conn)
+            form.add_proxy()
+            form.show()
+        self._forms_attached = True
+
     #
     # Hooks
     #
@@ -503,6 +575,9 @@ class SlaveView(gobject.GObject):
         if self.toplevel:
             self.toplevel.connect("key-press-event", controller.on_key_press)
 
+        # We have to wait until callbacks are connected to add the proxies
+        self._attach_forms()
+
     #
     # Slave handling
     #
@@ -557,7 +632,17 @@ class SlaveView(gobject.GObject):
         if not placeholder:
             raise AttributeError(
                   "slave container widget `%s' not found" % name)
-        parent = placeholder.get_parent()
+
+        # This is for glade-less Views, create an EventBox automatically
+        # for a holder
+        if isinstance(placeholder, gtk.Window):
+            parent = placeholder
+            placeholder = gtk.EventBox()
+            placeholder.set_border_width(6)
+            parent.add(placeholder)
+            placeholder.show()
+        else:
+            parent = placeholder.get_parent()
 
         if slave._accel_groups:
             # take care of accelerator groups; attach to parent window if we
@@ -599,8 +684,12 @@ class SlaveView(gobject.GObject):
             raise TypeError(
                 "widget to be replaced must be wrapped in eventbox")
 
-        # when attaching a slave we usually want it visible
-        parent.show()
+        # when attaching a slave we usually want it visible, the exception is
+        # views that are glade less are have a window created for them automatically,
+        # they need to be showed explicitly using view.show/show_all.
+        if parent.get_name() != 'KiwiViewWindow':
+            parent.show()
+
         # call slave's callback
         slave.on_attach(self)
 
@@ -835,10 +924,10 @@ class SlaveView(gobject.GObject):
         validation_log.info("%s: validate state=%r" % (
             self.__class__.__name__, self._validation))
         # Check if validation really changed
-        if self._valid == is_valid and force == False:
+        if self.is_valid == is_valid and force == False:
             return
 
-        self._valid = is_valid
+        self.is_valid = is_valid
         self.emit('validation-changed', is_valid)
 
         # FIXME: Remove and update all callsites to use validation-changed
